{% extends 'flask_statics_helper/base.html' %}
{% set STATICS_ENABLE_RESOURCE_BOOTSTRAP = True %}
{% set STATICS_ENABLE_RESOURCE_JQUERY = True %}

{% block html_body %}
    {% block navbar %}
    {% endblock navbar %}

    {% block content %}
    <div class="container">
        {% block container %}
        {% endblock container %}
    </div>
    {% endblock content %}
{% endblock html_body %}
